@@ -46,21 +46,8 @@ void NetworkPref::loadSettings()
     // get all the network devices and add them to the combo box
     const QList<QNetworkInterface> iface_list = QNetworkInterface::allInterfaces();
 
-    // FIXME KF5 const QList<Solid::Device> netlist = Solid::Device::listFromType(Solid::DeviceInterface::NetworkInterface);
-
     for (const QNetworkInterface &iface : iface_list) {
-        QIcon icon = QIcon::fromTheme(QStringLiteral("network-wired"));
-#if 0 // FIXME KF5
-        for (const Solid::Device& device : netlist) {
-            const Solid::NetworkInterface* netdev = device.as<Solid::NetworkInterface>();
-            if (netdev->ifaceName() == iface.name() && netdev->isWireless()) {
-                icon = QIcon::fromTheme(QStringLiteral("network-wireless"));
-                break;
-            }
-
-        }
-#endif
-
+        const QIcon icon = QIcon::fromTheme(QStringLiteral("network-wired"));
         combo_networkInterface->addItem(icon, iface.humanReadableName());
     }
     const QString iface = Settings::networkInterface();
