@@ -17,12 +17,11 @@ class MagnetGeneratorPlugin : public Plugin, public ViewListener
 {
     Q_OBJECT
 public:
-    MagnetGeneratorPlugin(QObject *parent, const QVariantList &args);
+    MagnetGeneratorPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~MagnetGeneratorPlugin() override;
 
     void load() override;
     void unload() override;
-    bool versionCheck(const QString &version) const override;
     QString parentPart() const override
     {
         return QStringLiteral("torrentactivity");
